"""
Performs pre-flight file check

Usage: python ./path/to/file_check.py /path/to/genome

e.g., on VACC that's ~/scratch/data/genome
"""

import os
import sys

MM10CHR4 = ['mm10.chr4',
            'rheMac3.chr3',
            'canFam3.chr14',
            'cavPor3.scaffold_11',
            'equCab2.chr4',
            'hg19.chr7',
            'oryCun2.chr10',
            'hg19.chr8',
            'rheMac3.chr8',
            'equCab2.chr9',
            'cavPor3.scaffold_64',
            'canFam3.chr29',
            'oryCun2.chr3',
            'susScr3.chr4',
            'cavPor3.scaffold_83',
            'susScr3.GL893631-2',
            'cavPor3.scaffold_0',
            'susScr3.GL893128-1',
            'rheMac3.chrUn_JH290722',
            'susScr3.GL893096-2',
            'hg19.chr6',
            'canFam3.chr12',
            'equCab2.chr10',
            'rheMac3.chrUn_JH290581',
            'cavPor3.scaffold_49',
            'susScr3.chr1',
            'oryCun2.chr12',
            'rheMac3.chr4',
            'susScr3.JH118404-1',
            'susScr3.JH118936-1',
            'susScr3.GL893960-2',
            'cavPor3.scaffold_12',
            'cavPor3.scaffold_2',
            'equCab2.chr23',
            'canFam3.chr11',
            'hg19.chr9',
            'rheMac3.chr15',
            'oryCun2.chr1',
            'susScr3.chr10',
            'cavPor3.scaffold_27',
            'equCab2.chr25',
            'susScr3.JH118626-1',
            'cavPor3.scaffold_93',
            'susScr3.GL895533-2',
            'susScr3.GL894206-2',
            'susScr3.GL893014-2',
            'oryCun2.chrUn0001',
            'susScr3.JH118639-1',
            'susScr3.JH118444-1',
            'susScr3.JH118412-1',
            'susScr3.GL892865-1',
            'susScr3.GL892806-1',
            'susScr3.GL895771-1',
            'canFam3.chr1',
            'cavPor3.scaffold_21',
            'susScr3.GL895946-1',
            'susScr3.GL894995-1',
            'susScr3.JH118524-1',
            'susScr3.GL894619-1',
            'susScr3.GL895471-2',
            'cavPor3.scaffold_88',
            'susScr3.chr6',
            'equCab2.chr2',
            'oryCun2.chr13',
            'hg19.chr1',
            'rheMac3.chr1',
            'canFam3.chr5',
            'susScr3.GL895774-1',
            'equCab2.chr5',
            'susScr3.GL892467-1',
            'susScr3.GL895755-1',
            'susScr3.GL896044-1',
            'susScr3.GL893269-1',
            'susScr3.GL895038-1',
            'susScr3.GL893593-1',
            'susScr3.GL893011-1',
            'susScr3.GL895204-1',
            'susScr3.GL893847-1',
            'susScr3.GL896137-1',
            'susScr3.GL893914-1',
            'susScr3.JH118970-1',
            'susScr3.GL895308-2',
            'susScr3.GL894855-1',
            'susScr3.GL895672-1',
            'susScr3.GL895603-2',
            'susScr3.JH118816-1',
            'susScr3.GL893071-1',
            'susScr3.GL894456-1',
            'susScr3.GL894077-1',
            'susScr3.GL895333-2',
            'cavPor3.scaffold_321',
            'cavPor3.scaffold_112',
            'canFam3.chr15',
            'susScr3.GL895158-1',
            'susScr3.GL893693-1',
            'cavPor3.scaffold_467',
            'cavPor3.scaffold_189',
            'susScr3.GL894874-1',
            'rheMac3.chrUn_JH291187',
            'cavPor3.scaffold_133',
            'cavPor3.scaffold_394',
            'susScr3.GL895352-1',
            'cavPor3.scaffold_165',
            'cavPor3.scaffold_143',
            'susScr3.GL895172-1',
            'cavPor3.scaffold_180',
            'susScr3.GL892424-2',
            'susScr3.GL896017-1',
            'susScr3.GL893006-1',
            'oryCun2.chrUn0006',
            'cavPor3.scaffold_25',
            'susScr3.GL893120-1',
            'susScr3.GL896104-1',
            'susScr3.GL895044-2',
            'susScr3.GL895950-1',
            'susScr3.GL896148-1',
            'susScr3.GL895583-1',
            'susScr3.GL892830-1',
            'susScr3.GL896222-1',
            'susScr3.GL895370-1',
            'susScr3.GL896547-1',
            'susScr3.GL893687-1',
            'susScr3.GL894198-1',
            'canFam3.chr2',
            'susScr3.GL896324-1',
            'susScr3.GL894350-2',
            'susScr3.JH118535-1',
            'susScr3.GL893661-1',
            'susScr3.GL896386-1',
            'susScr3.GL892805-1',
            'susScr3.GL893957-1',
            'susScr3.GL895417-2',
            'susScr3.GL893988-2',
            'susScr3.GL894193-1',
            'oryCun2.chrUn0217',
            'oryCun2.chrUn0423',
            'oryCun2.chrUn0699',
            'oryCun2.chrUn0093',
            'rheMac3.chr6',
            'oryCun2.chrUn0041',
            'oryCun2.chrUn0229',
            'oryCun2.chrUn0802',
            'rheMac3.chrUn_JH290750',
            'susScr3.GL896352-1',
            'susScr3.GL893555-1',
            'susScr3.GL896192-1',
            'susScr3.GL894445-1',
            'oryCun2.chrUn0478',
            'susScr3.JH118450-1',
            'cavPor3.scaffold_186',
            'oryCun2.chrUn0388',
            'rheMac3.chrUn_JH291010',
            'oryCun2.chrUn0902',
            'susScr3.GL895967-2',
            'oryCun2.chrUn1042',
            'oryCun2.chrUn1417']

MM10CHR6 = ['mm10.chr6',
            'rheMac3.chr3',
            'cavPor3.scaffold_11',
            'canFam3.chr14',
            'equCab2.chr4',
            'hg19.chr7',
            'oryCun2.chr10',
            'susScr3.chr9',
            'susScr3.JH118748-1',
            'susScr3.GL893433-2',
            'rheMac3.chrUn_JH291096',
            'oryCun2.chr7',
            'susScr3.chr18',
            'susScr3.GL894233-1',
            'cavPor3.scaffold_432',
            'cavPor3.scaffold_44',
            'susScr3.GL892730-2',
            'susScr3.JH118757-1',
            'susScr3.GL895571-2',
            'canFam3.chr16',
            'cavPor3.scaffold_10',
            'rheMac3.chrUn_JH292418',
            'oryCun2.chrUn0155',
            'oryCun2.chrUn0076',
            'oryCun2.chrUn0136',
            'oryCun2.chrUn0060',
            'oryCun2.chrUn0580',
            'susScr3.GL892960-2',
            'rheMac3.chrUn_JH292012',
            'rheMac3.chrUn_JH290921',
            'susScr3.GL892345-2',
            'susScr3.GL892911-1',
            'cavPor3.scaffold_32',
            'oryCun2.chrUn0108',
            'susScr3.GL893503-1',
            'susScr3.JH118684-1',
            'susScr3.JH118567-1',
            'susScr3.GL894194-2',
            'susScr3.JH118894-1',
            'susScr3.GL892808-2',
            'susScr3.JH118642-1',
            'cavPor3.scaffold_30',
            'oryCun2.chr15',
            'cavPor3.scaffold_48',
            'canFam3.chr32',
            'hg19.chr4',
            'rheMac3.chrUn_JH290493',
            'equCab2.chr3',
            'rheMac3.chr5',
            'susScr3.chr8',
            'rheMac3.chrUn_JH291363',
            'cavPor3.scaffold_22',
            'susScr3.GL894411-2',
            'rheMac3.chrUn_JH290389',
            'equCab2.chr2',
            'cavPor3.scaffold_7',
            'canFam3.chr19',
            'susScr3.GL894486-1',
            'hg19.chr1',
            'rheMac3.chr1',
            'equCab2.chr5',
            'oryCun2.chr13',
            'susScr3.GL894290-1',
            'canFam3.chr6',
            'susScr3.GL895663-1',
            'susScr3.GL896063-1',
            'susScr3.GL894355-1',
            'canFam3.chr5',
            'susScr3.chr6',
            'cavPor3.scaffold_37',
            'canFam3.chr17',
            'hg19.chr2',
            'equCab2.chr15',
            'susScr3.chr3',
            'oryCun2.chr2',
            'rheMac3.chr13',
            'susScr3.JH118982-1',
            'canFam3.chr10',
            'susScr3.JH118905-1',
            'canFam3.chr20',
            'hg19.chr3',
            'rheMac3.chr11',
            'susScr3.chr13',
            'equCab2.chr16',
            'oryCun2.chr9',
            'cavPor3.scaffold_120',
            'cavPor3.scaffold_187',
            'susScr3.JH118478-1',
            'equCab2.chrUn',
            'cavPor3.scaffold_109',
            'rheMac3.chr2',
            'cavPor3.scaffold_16',
            'susScr3.chr7',
            'cavPor3.scaffold_91',
            'cavPor3.scaffold_0',
            'susScr3.JH118521-1',
            'susScr3.GL894426-1',
            'susScr3.GL893524-1',
            'oryCun2.chrUn0005',
            'susScr3.JH118890-1',
            'susScr3.GL893397-2',
            'cavPor3.scaffold_87',
            'susScr3.GL893259-1',
            'susScr3.GL892916-1',
            'oryCun2.chrUn0104',
            'oryCun2.chrUn0565',
            'susScr3.JH118519-1',
            'cavPor3.scaffold_123',
            'rheMac3.chrUn_JH290780',
            'canFam3.chr28',
            'cavPor3.scaffold_62',
            'oryCun2.chr18',
            'susScr3.chr14',
            'equCab2.chr1',
            'rheMac3.chr9',
            'hg19.chr10',
            'oryCun2.chrUn0110',
            'oryCun2.chrUn0107',
            'rheMac3.chrUn_JH290540',
            'equCab2.chr29',
            'canFam3.chr2',
            'oryCun2.chr16',
            'canFam3.chr27',
            'equCab2.chr6',
            'hg19.chr12',
            'cavPor3.scaffold_95',
            'oryCun2.chr8',
            'susScr3.chr5',
            'cavPor3.scaffold_169',
            'hg19.chr22',
            'rheMac3.chr10',
            'oryCun2.chrUn0111',
            'cavPor3.scaffold_28',
            'susScr3.GL896371-1',
            'cavPor3.scaffold_107',
            'susScr3.GL894246-2',
            'susScr3.GL894715-1',
            'oryCun2.chrUn0083',
            'susScr3.GL893070-1',
            'susScr3.GL896456-1',
            'susScr3.GL893975-2',
            'susScr3.GL892381-1',
            'susScr3.GL893841-1',
            'cavPor3.scaffold_140',
            'cavPor3.scaffold_54',
            'susScr3.JH118955-1']

MM10CHR2 = ['mm10.chr2',
            'equCab2.chr29',
            'hg19.chr10',
            'oryCun2.chr16',
            'cavPor3.scaffold_141',
            'canFam3.chr2',
            'rheMac3.chr9',
            'susScr3.chr10',
            'cavPor3.scaffold_39',
            'rheMac3.chrUn_JH290710',
            'cavPor3.scaffold_16',
            'susScr3.GL895338-2',
            'susScr3.JH118762-1',
            'oryCun2.chrUn0052',
            'oryCun2.chrUn0212',
            'cavPor3.scaffold_120',
            'susScr3.GL893725-2',
            'cavPor3.scaffold_91',
            'rheMac3.chrUn_JH296391',
            'oryCun2.chrUn0026',
            'cavPor3.scaffold_109',
            'oryCun2.chr7',
            'cavPor3.scaffold_3',
            'equCab2.chr18',
            'hg19.chr2',
            'rheMac3.chr12',
            'canFam3.chr19',
            'susScr3.chr15',
            'rheMac3.chr7',
            'hg19.chr14',
            'equCab2.chr24',
            'canFam3.chr8',
            'equCab2.chr15',
            'oryCun2.chr2',
            'canFam3.chr3',
            'rheMac3.chr13',
            'cavPor3.scaffold_73',
            'canFam3.chr17',
            'susScr3.GL893900-2',
            'susScr3.chr3',
            'equCab2.chr25',
            'hg19.chr9',
            'rheMac3.chr15',
            'cavPor3.scaffold_18',
            'oryCun2.chrUn0169',
            'canFam3.chr9',
            'susScr3.chr1',
            'oryCun2.chrUn1100',
            'cavPor3.scaffold_27',
            'oryCun2.chrUn0522',
            'oryCun2.chrUn0066',
            'oryCun2.chrUn0149',
            'oryCun2.chrUn0448',
            'oryCun2.chrUn0440',
            'rheMac3.chrUn_JH291099',
            'oryCun2.chrUn0235',
            'oryCun2.chrUn0547',
            'oryCun2.chrUn0353',
            'oryCun2.chrUn0938',
            'oryCun2.chrUn0307',
            'susScr3.JH118695-1',
            'oryCun2.chrUn0001',
            'susScr3.JH118459-1',
            'cavPor3.scaffold_2',
            'canFam3.chr11',
            'susScr3.GL893074-1',
            'susScr3.GL896270-1',
            'susScr3.GL892755-1',
            'canFam3.chr36',
            'susScr3.GL895956-1',
            'susScr3.GL895692-1',
            'susScr3.GL893247-2',
            'susScr3.JH118596-1',
            'susScr3.GL894362-1',
            'susScr3.GL893835-2',
            'susScr3.GL893604-1',
            'susScr3.GL895386-1',
            'equCab2.chr12',
            'hg19.chr11',
            'rheMac3.chr14',
            'oryCun2.chr1',
            'susScr3.chr2',
            'canFam3.chr18',
            'cavPor3.scaffold_86',
            'susScr3.GL894573-1',
            'equCab2.chrUn',
            'cavPor3.scaffold_72',
            'cavPor3.scaffold_92',
            'susScr3.JH118591-1',
            'susScr3.GL893649-1',
            'equCab2.chr7',
            'cavPor3.scaffold_81',
            'canFam3.chr21',
            'cavPor3.scaffold_74',
            'susScr3.GL893210-2',
            'hg19.chr15',
            'susScr3.chr7',
            'canFam3.chr30',
            'equCab2.chr1',
            'cavPor3.scaffold_10',
            'oryCun2.chr17',
            'susScr3.JH118622-1',
            'susScr3.GL895676-1',
            'susScr3.GL894567-2',
            'rheMac3.chrUn_JH290790',
            'cavPor3.scaffold_23',
            'cavPor3.scaffold_24',
            'susScr3.JH118923-1',
            'susScr3.GL894208-1',
            'equCab2.chr22',
            'cavPor3.scaffold_8',
            'hg19.chr20',
            'rheMac3.chr10',
            'canFam3.chr24',
            'oryCun2.chr4',
            'susScr3.chr17',
            'susScr3.GL895578-1',
            'susScr3.GL893851-2',
            'rheMac3.chrX',
            'susScr3.GL895826-2',
            'susScr3.GL893746-2',
            'rheMac3.chrUn_JH291399',
            'rheMac3.chrUn_JH290703',
            'canFam3.chr23',
            'oryCun2.chrUn0043',
            'susScr3.GL896323-1',
            'rheMac3.chrUn_JH290728',
            'susScr3.GL893783-2',
            'cavPor3.scaffold_45',
            'susScr3.GL892260-2',
            'susScr3.GL894022-1',
            'susScr3.GL892785-2',
            'oryCun2.chrUn0020',
            'susScr3.GL893999-1',
            'oryCun2.chrUn0027',
            'rheMac3.chrUn_JH292322',
            'susScr3.GL896282-2',
            'oryCun2.chrUn0242',
            'cavPor3.scaffold_96',
            'oryCun2.chrUn0124',
            'oryCun2.chrUn0014',
            'oryCun2.chrUn0574',
            'cavPor3.scaffold_156',
            'oryCun2.chrUn0310',
            'oryCun2.chrUn0057',
            'cavPor3.scaffold_119',
            'oryCun2.chrUn0774',
            'susScr3.chr6',
            'susScr3.GL896364-1',
            'oryCun2.chrUn0374',
            'oryCun2.chrUn0530']

MM10CHR19 = ['canFam3.chr1',
             'canFam3.chr11',
             'canFam3.chr18',
             'canFam3.chr21',
             'canFam3.chr26',
             'canFam3.chr28',
             'cavPor3.scaffold_1',
             'cavPor3.scaffold_11',
             'cavPor3.scaffold_135',
             'cavPor3.scaffold_137',
             'cavPor3.scaffold_15',
             'cavPor3.scaffold_21',
             'cavPor3.scaffold_42',
             'cavPor3.scaffold_44',
             'cavPor3.scaffold_65',
             'cavPor3.scaffold_86',
             'equCab2.chr1',
             'equCab2.chr12',
             'equCab2.chr23',
             'hg19.chr10',
             'hg19.chr11',
             'hg19.chr9',
             'mm10.chr19',
             'oryCun2.chr1',
             'oryCun2.chr18',
             'oryCun2.chrUn0019',
             'oryCun2.chrUn0221',
             'oryCun2.chrUn0244',
             'oryCun2.chrUn0269',
             'oryCun2.chrUn0529',
             'oryCun2.chrUn0617',
             'oryCun2.chrUn0636',
             'oryCun2.chrUn0717',
             'oryCun2.chrUn0840',
             'oryCun2.chrUn1105',
             'oryCun2.chrUn1194',
             'rheMac3.chr12',
             'rheMac3.chr14',
             'rheMac3.chr15',
             'rheMac3.chr9',
             'rheMac3.chrUn_JH290838',
             'susScr3.chr1',
             'susScr3.chr14',
             'susScr3.chr2',
             'susScr3.chr4',
             'susScr3.GL892633-2',
             'susScr3.GL893640-2',
             'susScr3.GL894312-1',
             'susScr3.GL894367-1',
             'susScr3.GL894663-1',
             'susScr3.GL895120-1',
             'susScr3.GL895336-1',
             'susScr3.GL895853-2',
             'susScr3.GL895864-2',
             'susScr3.GL896152-2',
             'susScr3.GL896246-1',
             'susScr3.JH118431-1',
             'susScr3.JH118588-1',
             'susScr3.JH118839-1',
             'susScr3.JH118872-1',
             'susScr3.JH118911-1']

MM10CHR11 = ['mm10.chr11',
             'hg19.chr22',
             'rheMac3.chr10',
             'canFam3.chr26',
             'oryCun2.chr21',
             'cavPor3.scaffold_4',
             'susScr3.chr14',
             'equCab2.chr8',
             'oryCun2.chrUn0025',
             'equCab2.chr4',
             'hg19.chr7',
             'rheMac3.chr3',
             'susScr3.chr18',
             'cavPor3.scaffold_66',
             'oryCun2.chr10',
             'canFam3.chrUn_JH373316',
             'canFam3.chrUn_JH373278',
             'rheMac3.chrUn_JH290717',
             'cavPor3.scaffold_102',
             'susScr3.chr9',
             'oryCun2.chrUn0047',
             'canFam3.chr18',
             'cavPor3.scaffold_200',
             'susScr3.JH118990-1',
             'susScr3.chr3',
             'hg19.chr2',
             'cavPor3.scaffold_37',
             'rheMac3.chr13',
             'equCab2.chr15',
             'oryCun2.chr2',
             'canFam3.chr10',
             'susScr3.GL893664-2',
             'cavPor3.scaffold_48',
             'susScr3.JH118652-1',
             'susScr3.GL892822-1',
             'susScr3.GL895773-1',
             'cavPor3.scaffold_162',
             'cavPor3.scaffold_0',
             'susScr3.chr13',
             'canFam3.chr23',
             'equCab2.chr16',
             'hg19.chr3',
             'equCab2.chr14',
             'canFam3.chr4',
             'cavPor3.scaffold_17',
             'hg19.chr5',
             'rheMac3.chr6',
             'oryCun2.chr3',
             'susScr3.chr16',
             'hg19.chr16',
             'equCab2.chr13',
             'canFam3.chr6',
             'oryCun2.chrUn0452',
             'rheMac3.chr20',
             'susScr3.GL895563-1',
             'susScr3.GL893764-2',
             'susScr3.GL894319-1',
             'susScr3.GL894168-1',
             'susScr3.GL892391-1',
             'canFam3.chr11',
             'susScr3.GL893304-1',
             'cavPor3.scaffold_21',
             'oryCun2.chr11',
             'susScr3.chr2',
             'oryCun2.chrUn0032',
             'cavPor3.scaffold_255',
             'cavPor3.scaffold_176',
             'cavPor3.scaffold_81',
             'susScr3.JH118697-1',
             'susScr3.JH118674-1',
             'equCab2.chr21',
             'cavPor3.scaffold_1',
             'oryCun2.chrUn0349',
             'hg19.chr1',
             'rheMac3.chr1',
             'canFam3.chr16',
             'canFam3.chr14',
             'cavPor3.scaffold_6',
             'oryCun2.chrUn0370',
             'oryCun2.chrUn0417',
             'oryCun2.chrUn0450',
             'hg19.chr17',
             'rheMac3.chr16',
             'cavPor3.scaffold_65',
             'equCab2.chr11',
             'canFam3.chr5',
             'oryCun2.chrUn0222',
             'oryCun2.chrUn0410',
             'oryCun2.chrUn1334',
             'oryCun2.chrUn0119',
             'oryCun2.chrUn0322',
             'cavPor3.scaffold_71',
             'rheMac3.chrUn_JH290358',
             'susScr3.chr12',
             'oryCun2.chr19',
             'cavPor3.scaffold_61',
             'cavPor3.scaffold_32',
             'canFam3.chr9',
             'susScr3.GL893571-2',
             'susScr3.JH118861-1',
             'susScr3.GL895144-1',
             'susScr3.JH118784-1',
             'susScr3.GL892959-1',
             'rheMac3.chrUn_JH290984',
             'rheMac3.chrX',
             'cavPor3.scaffold_53',
             'susScr3.GL895387-1',
             'susScr3.GL894413-1',
             'susScr3.GL895585-2',
             'rheMac3.chrUn_JH292033',
             'susScr3.GL896494-1',
             'susScr3.GL896254-1',
             'susScr3.GL896426-1',
             'cavPor3.scaffold_67',
             'susScr3.JH118614-1',
             'susScr3.JH118425-1',
             'susScr3.GL894375-2',
             'susScr3.JH118785-1',
             'cavPor3.scaffold_3',
             'susScr3.JH118414-1',
             'susScr3.JH118937-1',
             'cavPor3.scaffold_76',
             'oryCun2.chrUn0210',
             'oryCun2.chrUn0292',
             'oryCun2.chrUn0147',
             'cavPor3.scaffold_317',
             'cavPor3.scaffold_193',
             'oryCun2.chrUn1026',
             'oryCun2.chrUn0145',
             'susScr3.GL896226-2',
             'oryCun2.chrUn0635',
             'oryCun2.chrUn0477',
             'oryCun2.chrUn0367',
             'susScr3.GL894007-1',
             'oryCun2.chrUn0933',
             'oryCun2.chrUn0571',
             'hg19.chr17_gl000204_random',
             'oryCun2.chrUn0426',
             'oryCun2.chrUn0592',
             'oryCun2.chrUn0941',
             'oryCun2.chrUn0584',
             'canFam3.chrUn_JH373243',
             'oryCun2.chrUn0168']

MM10CHR9 = ['mm10.chr9',
            'oryCun2.chr15',
            'susScr3.chr8',
            'canFam3.chr13',
            'equCab2.chr3',
            'hg19.chr4',
            'rheMac3.chr5',
            'cavPor3.scaffold_24',
            'rheMac3.chr14',
            'oryCun2.chr1',
            'susScr3.chr9',
            'equCab2.chr7',
            'hg19.chr11',
            'canFam3.chr5',
            'cavPor3.scaffold_19',
            'rheMac3.chr13',
            'canFam3.chr21',
            'susScr3.GL896049-1',
            'susScr3.JH118644-1',
            'cavPor3.scaffold_40',
            'rheMac3.chr10',
            'hg19.chr19',
            'canFam3.chr20',
            'oryCun2.chrUn0143',
            'cavPor3.scaffold_195',
            'rheMac3.chr19',
            'cavPor3.scaffold_236',
            'oryCun2.chrUn0135',
            'cavPor3.scaffold_172',
            'susScr3.chr2',
            'cavPor3.scaffold_368',
            'oryCun2.chrUn0216',
            'cavPor3.scaffold_226',
            'oryCun2.chrUn0748',
            'equCab2.chr4',
            'rheMac3.chr3',
            'cavPor3.scaffold_30',
            'hg19.chr7',
            'oryCun2.chr10',
            'susScr3.chr18',
            'canFam3.chr14',
            'oryCun2.chrUn0044',
            'rheMac3.chrUn_JH290448',
            'susScr3.GL892477-1',
            'susScr3.GL894750-2',
            'rheMac3.chrUn_JH290528',
            'oryCun2.chrUn0125',
            'susScr3.GL893223-2',
            'oryCun2.chrUn0084',
            'susScr3.GL894298-1',
            'cavPor3.scaffold_481',
            'cavPor3.scaffold_136',
            'oryCun2.chr17',
            'canFam3.chr30',
            'equCab2.chr1',
            'hg19.chr15',
            'rheMac3.chr7',
            'cavPor3.scaffold_23',
            'susScr3.chr1',
            'cavPor3.scaffold_98',
            'susScr3.chr7',
            'oryCun2.chrUn0048',
            'canFam3.chr3',
            'susScr3.GL893884-1',
            'oryCun2.chrUn0070',
            'susScr3.GL893828-2',
            'oryCun2.chrUn0336',
            'susScr3.GL892482-1',
            'susScr3.GL893363-2',
            'cavPor3.scaffold_147',
            'oryCun2.chrUn0413',
            'rheMac3.chr16',
            'oryCun2.chrUn0117',
            'susScr3.JH118811-1',
            'cavPor3.scaffold_5',
            'susScr3.GL896452-1',
            'oryCun2.chrUn0077',
            'oryCun2.chrUn0141',
            'oryCun2.chrUn0095',
            'cavPor3.scaffold_0',
            'oryCun2.chrUn0394',
            'cavPor3.scaffold_101',
            'susScr3.JH118910-1',
            'cavPor3.scaffold_499',
            'susScr3.GL894399-1',
            'cavPor3.scaffold_155',
            'rheMac3.chrUn_JH291060',
            'susScr3.GL893979-2',
            'hg19.chr6',
            'rheMac3.chr4',
            'oryCun2.chr12',
            'equCab2.chr20',
            'canFam3.chr12',
            'cavPor3.scaffold_141',
            'rheMac3.chrUn_JH290808',
            'susScr3.GL893744-2',
            'cavPor3.scaffold_58',
            'cavPor3.scaffold_4',
            'equCab2.chr10',
            'cavPor3.scaffold_12',
            'rheMac3.chrX',
            'cavPor3.scaffold_190',
            'oryCun2.chrUn0148',
            'oryCun2.chr14',
            'equCab2.chr16',
            'cavPor3.scaffold_8',
            'canFam3.chr23',
            'rheMac3.chr2',
            'hg19.chr3',
            'susScr3.chr13',
            'rheMac3.chr6',
            'susScr3.GL894654-1',
            'oryCun2.chrUn0071',
            'oryCun2.chrUn0073',
            'susScr3.GL894235-1',
            'oryCun2.chr9',
            'susScr3.JH118746-1',
            'susScr3.JH118489-1',
            'cavPor3.scaffold_7',
            'cavPor3.scaffold_16',
            'susScr3.GL895559-1',
            'rheMac3.chrUn_JH291656',
            'rheMac3.chrUn_JH290586',
            'rheMac3.chrUn_JH290339',
            'rheMac3.chr11',
            'cavPor3.scaffold_87',
            'oryCun2.chrUn0544',
            'rheMac3.chrUn_JH290627',
            'susScr3.GL895008-1']

MM10CHR3 = ['mm10.chr3',
            'hg19.chr8',
            'canFam3.chr29',
            'equCab2.chr9',
            'rheMac3.chr8',
            'cavPor3.scaffold_0',
            'oryCun2.chr3',
            'susScr3.chr4',
            'susScr3.GL893852-2',
            'rheMac3.chr4',
            'susScr3.JH118951-1',
            'rheMac3.chrUn_JH290346',
            'equCab2.chr16',
            'oryCun2.chr14',
            'canFam3.chr23',
            'hg19.chr3',
            'cavPor3.scaffold_8',
            'rheMac3.chr2',
            'susScr3.chr13',
            'equCab2.chr19',
            'canFam3.chr34',
            'cavPor3.scaffold_47',
            'cavPor3.scaffold_100',
            'susScr3.GL892397-1',
            'susScr3.GL892375-1',
            'susScr3.GL893733-2',
            'cavPor3.scaffold_7',
            'rheMac3.chr11',
            'equCab2.chr2',
            'hg19.chr4',
            'canFam3.chr19',
            'rheMac3.chr5',
            'susScr3.chr8',
            'oryCun2.chr15',
            'rheMac3.chrUn_JH293070',
            'susScr3.GL892663-2',
            'susScr3.GL895381-1',
            'susScr3.GL894066-1',
            'susScr3.GL893084-1',
            'susScr3.GL892269-1',
            'susScr3.GL895213-2',
            'equCab2.chr17',
            'hg19.chr13',
            'cavPor3.scaffold_6',
            'oryCun2.chrUn0021',
            'canFam3.chr25',
            'rheMac3.chr17',
            'susScr3.chr11',
            'equCab2.chrUn',
            'susScr3.GL895643-2',
            'oryCun2.chrUn0004',
            'susScr3.GL892963-1',
            'susScr3.GL895041-1',
            'susScr3.GL895111-2',
            'equCab2.chr5',
            'cavPor3.scaffold_33',
            'rheMac3.chrUn_JH290315',
            'cavPor3.scaffold_88',
            'canFam3.chr15',
            'oryCun2.chrUn0003',
            'susScr3.GL892826-1',
            'susScr3.GL896255-2',
            'susScr3.GL893911-1',
            'hg19.chr1',
            'rheMac3.chr1',
            'cavPor3.scaffold_56',
            'oryCun2.chr13',
            'canFam3.chr38',
            'canFam3.chr7',
            'cavPor3.scaffold_10',
            'rheMac3.chrUn_JH291084',
            'cavPor3.scaffold_2',
            'canFam3.chr17',
            'susScr3.GL894820-2',
            'susScr3.GL893333-2',
            'rheMac3.chrUn_JH293294',
            'susScr3.GL893511-2',
            'susScr3.GL894828-2',
            'susScr3.GL895442-2',
            'canFam3.chr6',
            'susScr3.GL894881-2',
            'susScr3.GL893192-2',
            'susScr3.GL892439-2',
            'rheMac3.chrUn_JH291031',
            'rheMac3.chrUn_JH290371',
            'canFam3.chrUn_AAEX03020568',
            'rheMac3.chrUn_JH290865',
            'susScr3.GL893226-1',
            'susScr3.GL895518-1',
            'susScr3.GL893831-2',
            'canFam3.chr32',
            'cavPor3.scaffold_43',
            'susScr3.GL895163-1',
            'susScr3.GL896369-1',
            'rheMac3.chrUn_JH290568',
            'equCab2.chr3',
            'susScr3.GL895778-1',
            'susScr3.JH118721-1',
            'cavPor3.scaffold_22',
            'susScr3.GL894997-1',
            'susScr3.GL894988-1',
            'susScr3.JH118581-1',
            'susScr3.GL895915-2',
            'susScr3.chr6',
            'rheMac3.chrUn_JH290372',
            'susScr3.GL893689-1',
            'susScr3.GL892793-2',
            'susScr3.GL893707-2',
            'rheMac3.chr14',
            'susScr3.JH118723-1',
            'susScr3.GL894184-2',
            'susScr3.GL893754-1',
            'susScr3.GL892463-1',
            'rheMac3.chrUn_JH290386',
            'susScr3.GL894461-1']

if __name__ == '__main__':

    DATA_PATH = sys.argv[1]

    BIG_LIST = list(set(MM10CHR19 + MM10CHR11 + MM10CHR9 +
                        MM10CHR2 + MM10CHR3 + MM10CHR4))

    for x in BIG_LIST:
        species, chrom = x.split('.')
        f = os.path.join(DATA_PATH, species, chrom + '.fa')
        if not os.path.isfile(f):
            print("Missing: {}".format(f))
